@@ -2,12 +2,12 @@ from tkinter import *
 import sys
 import os
 from tkinter.ttk import Notebook
-
+import re
 from appium_selector.Helpers.Config import GetConfig
 from appium_selector.Helpers.GridConnector import GridConnector
 from appium_selector.Helpers.LocalConnector import LocalConnector
 from appium_selector.Helpers.SauceConnector import SauceConnector
-
+from appium_selector.Helpers.MCConnector import MCConnector
 
 class DeviceSelector:
 
@@ -17,6 +17,7 @@ class DeviceSelector:
     local = LocalConnector()
     grid = GridConnector()
     sauce = SauceConnector()
+    mc = MCConnector()
 
     def __init__(self, parallel=False, platform='mobile'):
         self.parallel = parallel
@@ -33,8 +34,6 @@ class DeviceSelector:
         self.note = Notebook(self.root)
 
         # Set Window Properties
-        if sys.platform.lower() == 'windows' or sys.platform.lower() == 'win32':
-            win.iconbitmap(default=os.path.join(self.BASE_DIR, 'runner.ico'))
         win.wm_title("Test Runner")
         win.minsize(width=500, height=500)
 
@@ -82,6 +81,11 @@ class DeviceSelector:
             mobileData.append(node)
             self.listboxMobile.insert(END, node.displayString())
 
+        mcNodes = self.mc.mobileNodes
+        for node in mcNodes:
+            mobileData.append(node)
+            self.listboxMobile.insert(END, node.displayString())
+
         self.mobileData = mobileData
 
         self.listboxMobile.insert(END, 'Local Device')
@@ -121,6 +125,17 @@ class DeviceSelector:
         for node in sauceNodes:
             webData.append(node)
             self.listboxDesktop.insert(END, node.displayString())
+
+        sauceNodes = self.sauce.mobileWebNodes
+        for node in sauceNodes:
+            webData.append(node)
+            self.listboxDesktop.insert(END, node.displayString())
+
+        mcNodes = self.mc.webNodes
+        for node in mcNodes:
+            webData.append(node)
+            self.listboxDesktop.insert(END, node.displayString())
+
         self.webData = webData
 
         self.frame = Frame(win)
@@ -143,18 +158,43 @@ class DeviceSelector:
             self.note.add(mobileFrame, text='Mobile')
         self.note.pack(fill=BOTH, expand=1)
 
+        # allow double clicking in listbox to select a browser
+        self.listboxMobile.bind('<Double-1>', lambda x: self._saveDevices())
+        self.listboxDesktop.bind('<Double-1>', lambda x: self._saveDevicesDesktop())
+
     def _toggleMustard(self):
         self.mustard = not self.mustard
 
-    def getDevice(self):
-        self.start()
-        self.root.mainloop()
-        self.root.destroy()
-        output = []
-        for x in range(len(self.devices)):
-            dc = self.devices[x].desiredCaps(mustard=self.mustard)
-            output.append(dc)
-        return output
+    def getDevice(self, filter=None, mustard=True):
+        if filter:
+            #webNodes = self.grid.webNodes
+            #mobileNodes = self.grid.mobileNodes
+            if self.platform:
+                if self.platform == 'desktop':
+                    nodes = self.grid.webNodes + self.sauce.webNodes
+                elif self.platform == 'mobile':
+                    nodes = self.grid.mobileNodes + self.sauce.mobileNodes
+                else:
+                    nodes = self.grid.webNodes + self.grid.mobileNodes + self.sauce.webNodes + self.sauce.mobileNodes + self.sauce.mobileWebNodes
+            output=[]
+            for node in nodes:
+                if re.search(filter, node.displayString()):
+                    dc = node.desiredCaps(mustard=mustard)
+                    output.append(dc)
+            return output
+        else:
+            self.start()
+            # for osx bring selector window to the front
+            if sys.platform.lower() == 'darwin':  # Mac OS
+                self.root.lift()
+                self.root.attributes('-topmost', True)
+            self.root.mainloop()
+            self.root.destroy()
+            output = []
+            for x in range(len(self.devices)):
+                dc = self.devices[x].desiredCaps(mustard=self.mustard)
+                output.append(dc)
+            return output
 
     def _saveDevicesDesktop(self):
 
